{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "contig LCA",
            "doc": "create contig LCA from rRNA and Protein LCAs\n>find_contig_lca.py --rna <rnaLCA> --prot <protLCA> --scg <scgs> --output <outName>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "find_contig_lca.log",
            "stderr": "find_contig_lca.error",
            "inputs": [
                {
                    "type": "string",
                    "doc": "Output expanded contig LCA",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#find_contig_lca.tool.cwl/outName"
                },
                {
                    "type": "File",
                    "doc": "Input expanded protein LCA file",
                    "inputBinding": {
                        "prefix": "--prot"
                    },
                    "id": "#find_contig_lca.tool.cwl/protLCA"
                },
                {
                    "type": "File",
                    "doc": "Input expanded rna LCA file",
                    "inputBinding": {
                        "prefix": "--rna"
                    },
                    "id": "#find_contig_lca.tool.cwl/rnaLCA"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "md5 single copy gene file",
                    "inputBinding": {
                        "prefix": "--scg"
                    },
                    "id": "#find_contig_lca.tool.cwl/scgs"
                }
            ],
            "baseCommand": [
                "find_contig_lca.py"
            ],
            "arguments": [
                {
                    "valueFrom": "--verbose"
                }
            ],
            "id": "#find_contig_lca.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#find_contig_lca.tool.cwl/error",
                    "outputBinding": {
                        "glob": "find_contig_lca.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#find_contig_lca.tool.cwl/info",
                    "outputBinding": {
                        "glob": "find_contig_lca.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output expanded contig LCA file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#find_contig_lca.tool.cwl/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "abundance profile",
            "doc": "create abundance profile from expanded annotated sims files\nmd5:    sims_abundance.py -t md5 -i <input> -o <output> --coverage <coverage> --cluster <cluster> --md5index <md5index>\nlca:    sims_abundance.py -t lca -i <input> -o <output> --coverage <coverage> --cluster <cluster>\nsource: sims_abundance.py -t source -i <input> -o <output> --coverage <coverage> --cluster <cluster>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sims_abundance.log",
            "stderr": "sims_abundance.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--cluster"
                            }
                        }
                    ],
                    "doc": "Optional input file(s), cluster mapping",
                    "id": "#sims_abundance.tool.cwl/cluster"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Optional input file, assembly coverage",
                    "inputBinding": {
                        "prefix": "--coverage"
                    },
                    "id": "#sims_abundance.tool.cwl/coverage"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-i"
                        }
                    },
                    "doc": "Input expanded sims file",
                    "id": "#sims_abundance.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Optional input file, md5,seek,length",
                    "inputBinding": {
                        "prefix": "--md5_index"
                    },
                    "id": "#sims_abundance.tool.cwl/md5index"
                },
                {
                    "type": "string",
                    "doc": "Output abundance profile",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#sims_abundance.tool.cwl/outName"
                },
                {
                    "type": "string",
                    "doc": "Profile type",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#sims_abundance.tool.cwl/profileType"
                }
            ],
            "baseCommand": [
                "sims_abundance.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sims_abundance.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sims_abundance.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sims_abundance.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sims_abundance.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output abundance profile file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#sims_abundance.tool.cwl/output"
                }
            ],
            "id": "#sims_abundance.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GNU sort",
            "doc": "sort text file base on given field(s)",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sort.log",
            "stderr": "sort.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "use SEP instead of non-blank to blank transition, default is tab",
                    "inputBinding": {
                        "prefix": "-t",
                        "valueFrom": "$(\"\\u0009\")"
                    },
                    "id": "#sort.tool.cwl/field"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Files to sort",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#sort.tool.cwl/input"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "doc": "start a key at POS1, end it at POS2 (origin 1)",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sort.tool.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "merge only, the input files are assumed to be pre-sorted",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#sort.tool.cwl/merge"
                },
                {
                    "type": "string",
                    "doc": "write result to FILE instead of standard output",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#sort.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "-T",
                    "valueFrom": "$(runtime.tmpdir)"
                },
                {
                    "prefix": "-S",
                    "valueFrom": "$(runtime.ram)M"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sort.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sort.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "The sorted file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#sort.tool.cwl/output"
                }
            ],
            "id": "#sort.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "uncluster sims",
            "doc": "expand out similarity file (blast m8) by turning each cluster seed hit into a hit per cluster member\n>uncluster_sims.py <input> <outName> --cfile <cluster> --position <position>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "uncluster_sims.log",
            "stderr": "uncluster_sims.error",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-c"
                        }
                    },
                    "doc": "Input cluster mapping files",
                    "id": "#uncluster_sims.tool.cwl/clustMap"
                },
                {
                    "type": "string",
                    "doc": "Output unclustered similarity",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#uncluster_sims.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Column position of query in sims file, default is 1",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--position"
                    },
                    "id": "#uncluster_sims.tool.cwl/position"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-i"
                        }
                    },
                    "doc": "Input similarity hit files",
                    "id": "#uncluster_sims.tool.cwl/simHit"
                }
            ],
            "baseCommand": [
                "uncluster_sims.py"
            ],
            "arguments": [
                {
                    "valueFrom": "--verbose"
                },
                {
                    "prefix": "--db",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#uncluster_sims.tool.cwl/error",
                    "outputBinding": {
                        "glob": "uncluster_sims.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#uncluster_sims.tool.cwl/info",
                    "outputBinding": {
                        "glob": "uncluster_sims.log"
                    }
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Output unclustered similarity file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#uncluster_sims.tool.cwl/output"
                }
            ],
            "id": "#uncluster_sims.tool.cwl"
        },
        {
            "class": "Workflow",
            "label": "abundance",
            "doc": "abundace profiles from annotated files, for protein and/or rna",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/coverage"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/expandSims"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/filterSims"
                },
                {
                    "type": "string",
                    "id": "#main/jobid"
                },
                {
                    "type": "File",
                    "id": "#main/m5nrSCG"
                },
                {
                    "type": "File",
                    "id": "#main/md5index"
                },
                {
                    "type": "File",
                    "id": "#main/protClustMap"
                },
                {
                    "type": "File",
                    "id": "#main/protExpandLca"
                },
                {
                    "type": "File",
                    "id": "#main/rnaClustMap"
                },
                {
                    "type": "File",
                    "id": "#main/rnaExpandLca"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/lcaProfile/contigLCA",
                    "id": "#main/lcaProfileOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/md5Profile/output",
                    "id": "#main/md5ProfileOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sourceStats/output",
                    "id": "#main/sourceStatsOut"
                }
            ],
            "steps": [
                {
                    "run": "#contig-lca.workflow.cwl",
                    "label": "LCA Profile",
                    "in": [
                        {
                            "source": "#main/coverage",
                            "id": "#main/lcaProfile/coverage"
                        },
                        {
                            "source": "#main/jobid",
                            "id": "#main/lcaProfile/jobid"
                        },
                        {
                            "source": "#main/m5nrSCG",
                            "id": "#main/lcaProfile/m5nrSCG"
                        },
                        {
                            "source": "#main/protClustMap",
                            "id": "#main/lcaProfile/protClustMap"
                        },
                        {
                            "source": "#main/protExpandLca",
                            "id": "#main/lcaProfile/protExpandLca"
                        },
                        {
                            "source": "#main/rnaClustMap",
                            "id": "#main/lcaProfile/rnaClustMap"
                        },
                        {
                            "source": "#main/rnaExpandLca",
                            "id": "#main/lcaProfile/rnaExpandLca"
                        }
                    ],
                    "out": [
                        "#main/lcaProfile/contigLCA"
                    ],
                    "id": "#main/lcaProfile"
                },
                {
                    "run": "#sims_abundance.tool.cwl",
                    "label": "Abundance Profile",
                    "in": [
                        {
                            "source": [
                                "#main/rnaClustMap",
                                "#main/protClustMap"
                            ],
                            "id": "#main/md5Profile/cluster"
                        },
                        {
                            "source": "#main/coverage",
                            "id": "#main/md5Profile/coverage"
                        },
                        {
                            "source": "#main/filterSims",
                            "id": "#main/md5Profile/input"
                        },
                        {
                            "source": "#main/md5index",
                            "id": "#main/md5Profile/md5index"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).700.annotation.md5.abundance",
                            "id": "#main/md5Profile/outName"
                        },
                        {
                            "valueFrom": "md5",
                            "id": "#main/md5Profile/profileType"
                        }
                    ],
                    "out": [
                        "#main/md5Profile/output"
                    ],
                    "id": "#main/md5Profile"
                },
                {
                    "run": "#sims_abundance.tool.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/rnaClustMap",
                                "#main/protClustMap"
                            ],
                            "id": "#main/sourceStats/cluster"
                        },
                        {
                            "source": "#main/coverage",
                            "id": "#main/sourceStats/coverage"
                        },
                        {
                            "source": "#main/expandSims",
                            "id": "#main/sourceStats/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).700.annotation.source.stats",
                            "id": "#main/sourceStats/outName"
                        },
                        {
                            "valueFrom": "source",
                            "id": "#main/sourceStats/profileType"
                        }
                    ],
                    "out": [
                        "#main/sourceStats/output"
                    ],
                    "id": "#main/sourceStats"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "label": "contig LCA",
            "doc": "create LCA consistant across input contigs contigs\norder of precedence - rRNA, single copy gene, LCA of genes\n",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#contig-lca.workflow.cwl/coverage"
                },
                {
                    "type": "string",
                    "id": "#contig-lca.workflow.cwl/jobid"
                },
                {
                    "type": "File",
                    "id": "#contig-lca.workflow.cwl/m5nrSCG"
                },
                {
                    "type": "File",
                    "id": "#contig-lca.workflow.cwl/protClustMap"
                },
                {
                    "type": "File",
                    "id": "#contig-lca.workflow.cwl/protExpandLca"
                },
                {
                    "type": "File",
                    "id": "#contig-lca.workflow.cwl/rnaClustMap"
                },
                {
                    "type": "File",
                    "id": "#contig-lca.workflow.cwl/rnaExpandLca"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#contig-lca.workflow.cwl/abundanceLca/output",
                    "id": "#contig-lca.workflow.cwl/contigLCA"
                }
            ],
            "steps": [
                {
                    "run": "#sims_abundance.tool.cwl",
                    "in": [
                        {
                            "source": "#contig-lca.workflow.cwl/coverage",
                            "id": "#contig-lca.workflow.cwl/abundanceLca/coverage"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/expandLca/output",
                            "valueFrom": "${ return [self]; }",
                            "id": "#contig-lca.workflow.cwl/abundanceLca/input"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/jobid",
                            "valueFrom": "$(self).700.annotation.lca.abundance",
                            "id": "#contig-lca.workflow.cwl/abundanceLca/outName"
                        },
                        {
                            "valueFrom": "lca",
                            "id": "#contig-lca.workflow.cwl/abundanceLca/profileType"
                        }
                    ],
                    "out": [
                        "#contig-lca.workflow.cwl/abundanceLca/output"
                    ],
                    "id": "#contig-lca.workflow.cwl/abundanceLca"
                },
                {
                    "run": "#find_contig_lca.tool.cwl",
                    "in": [
                        {
                            "source": "#contig-lca.workflow.cwl/jobid",
                            "valueFrom": "$(self).650.contig.expand.lca",
                            "id": "#contig-lca.workflow.cwl/expandLca/outName"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/sortProt/output",
                            "id": "#contig-lca.workflow.cwl/expandLca/protLCA"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/sortRna/output",
                            "id": "#contig-lca.workflow.cwl/expandLca/rnaLCA"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/m5nrSCG",
                            "id": "#contig-lca.workflow.cwl/expandLca/scgs"
                        }
                    ],
                    "out": [
                        "#contig-lca.workflow.cwl/expandLca/output"
                    ],
                    "id": "#contig-lca.workflow.cwl/expandLca"
                },
                {
                    "run": "#sort.tool.cwl",
                    "in": [
                        {
                            "source": "#contig-lca.workflow.cwl/unclusterProt/output",
                            "id": "#contig-lca.workflow.cwl/sortProt/input"
                        },
                        {
                            "valueFrom": "$([\"2,2\"])",
                            "id": "#contig-lca.workflow.cwl/sortProt/key"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/unclusterProt/output",
                            "valueFrom": "$(self[0].basename).sort",
                            "id": "#contig-lca.workflow.cwl/sortProt/outName"
                        }
                    ],
                    "out": [
                        "#contig-lca.workflow.cwl/sortProt/output"
                    ],
                    "id": "#contig-lca.workflow.cwl/sortProt"
                },
                {
                    "run": "#sort.tool.cwl",
                    "in": [
                        {
                            "source": "#contig-lca.workflow.cwl/unclusterRna/output",
                            "id": "#contig-lca.workflow.cwl/sortRna/input"
                        },
                        {
                            "valueFrom": "$([\"2,2\"])",
                            "id": "#contig-lca.workflow.cwl/sortRna/key"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/unclusterRna/output",
                            "valueFrom": "$(self[0].basename).sort",
                            "id": "#contig-lca.workflow.cwl/sortRna/outName"
                        }
                    ],
                    "out": [
                        "#contig-lca.workflow.cwl/sortRna/output"
                    ],
                    "id": "#contig-lca.workflow.cwl/sortRna"
                },
                {
                    "run": "#uncluster_sims.tool.cwl",
                    "in": [
                        {
                            "source": "#contig-lca.workflow.cwl/protClustMap",
                            "valueFrom": "${ return [self]; }",
                            "id": "#contig-lca.workflow.cwl/unclusterProt/clustMap"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/protExpandLca",
                            "valueFrom": "$(self.basename).uncluster",
                            "id": "#contig-lca.workflow.cwl/unclusterProt/outName"
                        },
                        {
                            "valueFrom": "${ return 2; }",
                            "id": "#contig-lca.workflow.cwl/unclusterProt/position"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/protExpandLca",
                            "valueFrom": "${ return [self]; }",
                            "id": "#contig-lca.workflow.cwl/unclusterProt/simHit"
                        }
                    ],
                    "out": [
                        "#contig-lca.workflow.cwl/unclusterProt/output"
                    ],
                    "id": "#contig-lca.workflow.cwl/unclusterProt"
                },
                {
                    "run": "#uncluster_sims.tool.cwl",
                    "in": [
                        {
                            "source": "#contig-lca.workflow.cwl/rnaClustMap",
                            "valueFrom": "${ return [self]; }",
                            "id": "#contig-lca.workflow.cwl/unclusterRna/clustMap"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/rnaExpandLca",
                            "valueFrom": "$(self.basename).uncluster",
                            "id": "#contig-lca.workflow.cwl/unclusterRna/outName"
                        },
                        {
                            "valueFrom": "${ return 2; }",
                            "id": "#contig-lca.workflow.cwl/unclusterRna/position"
                        },
                        {
                            "source": "#contig-lca.workflow.cwl/rnaExpandLca",
                            "valueFrom": "${ return [self]; }",
                            "id": "#contig-lca.workflow.cwl/unclusterRna/simHit"
                        }
                    ],
                    "out": [
                        "#contig-lca.workflow.cwl/unclusterRna/output"
                    ],
                    "id": "#contig-lca.workflow.cwl/unclusterRna"
                }
            ],
            "id": "#contig-lca.workflow.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
